# MachXO3L Boards

The {py:mod}`torii_boards.lattice.machxo3` module provides a collection of Lattice MachXO3L FPGA development boards, they are based off the Torii {py:class}`MachXO3LPlatform <torii.platform.vendor.lattice.machxo_2_3l.MachXO3LPlatform>` platform and support the [Diamond] toolchain.

```{eval-rst}
.. autoclass:: torii_boards.lattice.machxo3.MachXO3SKPlatform
  :members:
```

[Diamond]: https://www.latticesemi.com/latticediamond
